@@ -2,7 +2,7 @@ use super::{
     super::{
         super::{DomainWithPort, Endpoint, IpAddrWithPort},
         ApiResult, Authorization, AuthorizationError, AuthorizationProvider, CallbackContextImpl,
-        ExtendedCallbackContextImpl, RequestParts, ResolveAnswers, ResolveOptions, ResolveResult, ResponseError,
+        ExtendedCallbackContextImpl, InnerRequestParts, ResolveAnswers, ResolveOptions, ResolveResult, ResponseError,
         ResponseErrorKind, RetriedStatsInfo, RetryDecision, SimplifiedCallbackContext, SyncResponse,
     },
     domain_or_ip_addr::DomainOrIpAddr,
@@ -25,7 +25,7 @@ use {
 
 pub(super) fn make_request<'r, B: Default + 'r>(
     url: Uri,
-    request: &'r RequestParts<'r>,
+    request: &'r InnerRequestParts<'r>,
     body: B,
     extensions: Extensions,
     resolved_ips: &'r [IpAddr],
@@ -46,16 +46,21 @@ pub(super) fn make_request<'r, B: Default + 'r>(
         .build()
 }
 
-pub(super) fn extract_ips_from(domain_or_ip: &DomainOrIpAddr) -> Cow<[IpAddrWithPort]> {
+pub(super) fn extract_ips_from(
+    domain_or_ip: &DomainOrIpAddr,
+) -> (Cow<'_, [IpAddrWithPort]>, Option<&'_ DomainWithPort>) {
     match domain_or_ip {
-        DomainOrIpAddr::Domain { resolved_ips, .. } => Cow::Borrowed(resolved_ips),
-        &DomainOrIpAddr::IpAddr(ip_addr) => Cow::Owned(vec![ip_addr]),
+        DomainOrIpAddr::Domain {
+            domain_with_port,
+            resolved_ips,
+        } => (Cow::Borrowed(resolved_ips), Some(domain_with_port)),
+        &DomainOrIpAddr::IpAddr(ip_addr) => (Cow::Owned(vec![ip_addr]), None),
     }
 }
 
 pub(super) fn make_url(
     domain_or_ip: &DomainOrIpAddr,
-    request: &RequestParts<'_>,
+    request: &InnerRequestParts<'_>,
     retried: &RetriedStatsInfo,
 ) -> Result<(Uri, Vec<IpAddr>), TryError> {
     return _make_url(domain_or_ip, request).map_err(|err| {
@@ -65,7 +70,10 @@ pub(super) fn make_url(
         )
     });
 
-    fn _make_url(domain_or_ip: &DomainOrIpAddr, request: &RequestParts<'_>) -> Result<(Uri, Vec<IpAddr>), InvalidUri> {
+    fn _make_url(
+        domain_or_ip: &DomainOrIpAddr,
+        request: &InnerRequestParts<'_>,
+    ) -> Result<(Uri, Vec<IpAddr>), InvalidUri> {
         let mut resolved_ip_addrs = Vec::new();
         let scheme = if request.use_https() {
             Scheme::HTTPS
@@ -138,7 +146,7 @@ pub(super) async fn reset_async_request_body(
 }
 
 pub(super) fn call_before_backoff_callbacks(
-    request: &RequestParts<'_>,
+    request: &InnerRequestParts<'_>,
     built: &mut HttpRequestParts<'_>,
     retried: &RetriedStatsInfo,
     delay: Duration,
@@ -160,7 +168,7 @@ pub(super) fn call_before_backoff_callbacks(
 }
 
 pub(super) fn call_after_backoff_callbacks(
-    request: &RequestParts<'_>,
+    request: &InnerRequestParts<'_>,
     built: &mut HttpRequestParts<'_>,
     retried: &RetriedStatsInfo,
     delay: Duration,
@@ -182,7 +190,7 @@ pub(super) fn call_after_backoff_callbacks(
 }
 
 fn call_to_resolve_domain_callbacks(
-    request: &RequestParts<'_>,
+    request: &InnerRequestParts<'_>,
     domain: &str,
     extensions: &mut Extensions,
     retried: &RetriedStatsInfo,
@@ -205,7 +213,7 @@ fn call_to_resolve_domain_callbacks(
 }
 
 fn call_domain_resolved_callbacks(
-    request: &RequestParts<'_>,
+    request: &InnerRequestParts<'_>,
     domain: &str,
     answers: &ResolveAnswers,
     extensions: &mut Extensions,
@@ -229,7 +237,7 @@ fn call_domain_resolved_callbacks(
 }
 
 fn call_to_choose_ips_callbacks(
-    request: &RequestParts<'_>,
+    request: &InnerRequestParts<'_>,
     ips: &[IpAddrWithPort],
     extensions: &mut Extensions,
     retried: &RetriedStatsInfo,
@@ -249,7 +257,7 @@ fn call_to_choose_ips_callbacks(
 }
 
 fn call_ips_chosen_callbacks(
-    request: &RequestParts<'_>,
+    request: &InnerRequestParts<'_>,
     ips: &[IpAddrWithPort],
     chosen: &[IpAddrWithPort],
     extensions: &mut Extensions,
@@ -273,7 +281,7 @@ fn call_ips_chosen_callbacks(
 }
 
 pub(super) fn call_before_request_signed_callbacks(
-    request: &RequestParts<'_>,
+    request: &InnerRequestParts<'_>,
     built: &mut HttpRequestParts<'_>,
     retried: &RetriedStatsInfo,
 ) -> Result<(), TryError> {
@@ -295,7 +303,7 @@ pub(super) fn call_before_request_signed_callbacks(
 }
 
 pub(super) fn call_after_request_signed_callbacks(
-    request: &RequestParts<'_>,
+    request: &InnerRequestParts<'_>,
     built: &mut HttpRequestParts<'_>,
     retried: &RetriedStatsInfo,
 ) -> Result<(), TryError> {
@@ -314,7 +322,7 @@ pub(super) fn call_after_request_signed_callbacks(
 }
 
 pub(super) fn call_response_callbacks(
-    request: &RequestParts<'_>,
+    request: &InnerRequestParts<'_>,
     built: &mut HttpRequestParts<'_>,
     retried: &RetriedStatsInfo,
     response: &ResponseParts,
@@ -331,7 +339,7 @@ pub(super) fn call_response_callbacks(
 }
 
 pub(super) fn call_error_callbacks(
-    request: &RequestParts<'_>,
+    request: &InnerRequestParts<'_>,
     built: &mut HttpRequestParts<'_>,
     retried: &RetriedStatsInfo,
     response_error: &ResponseError,
@@ -394,7 +402,7 @@ fn handle_sign_request_error(err: AuthorizationError, retried: &RetriedStatsInfo
 }
 
 pub(super) fn resolve(
-    request: &RequestParts<'_>,
+    request: &InnerRequestParts<'_>,
     domain_with_port: &DomainWithPort,
     extensions: &mut Extensions,
     retried: &RetriedStatsInfo,
@@ -412,7 +420,7 @@ pub(super) fn resolve(
         .collect());
 
     fn with_resolve_domain(
-        request: &RequestParts<'_>,
+        request: &InnerRequestParts<'_>,
         domain: &str,
         extensions: &mut Extensions,
         retried: &RetriedStatsInfo,
@@ -426,7 +434,7 @@ pub(super) fn resolve(
 }
 
 pub(super) fn choose(
-    request: &RequestParts<'_>,
+    request: &InnerRequestParts<'_>,
     ips: &[IpAddrWithPort],
     extensions: &mut Extensions,
     retried: &RetriedStatsInfo,
@@ -502,7 +510,7 @@ fn make_unexpected_status_code_error(parts: &ResponseParts, retried: &RetriedSta
 #[cfg(feature = "async")]
 mod async_utils {
     use super::{
-        super::super::{AsyncResponse, RequestParts},
+        super::super::{AsyncResponse, InnerRequestParts},
         *,
     };
     use qiniu_http::AsyncRequest as AsyncHttpRequest;
@@ -523,7 +531,7 @@ mod async_utils {
     }
 
     pub(in super::super) async fn async_resolve(
-        parts: &RequestParts<'_>,
+        parts: &InnerRequestParts<'_>,
         domain_with_port: &DomainWithPort,
         extensions: &mut Extensions,
         retried: &RetriedStatsInfo,
@@ -546,7 +554,7 @@ mod async_utils {
             .collect());
 
         async fn with_resolve_domain<F: FnOnce() -> Fu, Fu: Future<Output = ResolveResult>>(
-            parts: &RequestParts<'_>,
+            parts: &InnerRequestParts<'_>,
             domain: &str,
             extensions: &mut Extensions,
             retried: &RetriedStatsInfo,
@@ -562,7 +570,7 @@ mod async_utils {
     }
 
     pub(in super::super) async fn async_choose(
-        parts: &RequestParts<'_>,
+        parts: &InnerRequestParts<'_>,
         ips: &[IpAddrWithPort],
         extensions: &mut Extensions,
         retried: &RetriedStatsInfo,
