@@ -6,6 +6,7 @@ use super::{
     RequestRetrier, ResolveAnswers, Resolver, ResponseError, ShuffledChooser, ShuffledResolver, SimpleResolver,
     SimplifiedCallbackContext, SubnetChooser, SyncRequestBuilder, TimeoutResolver,
 };
+use assert_impl::assert_impl;
 use cfg_if::cfg_if;
 use qiniu_http::{
     CallbackResult, HeaderName, HeaderValue, HttpCaller, Method, ResponseParts, StatusCode, TransferProgressInfo,
@@ -31,6 +32,32 @@ use super::AsyncRequestBuilder;
 ///
 /// ### 私有云获取当前账户的 Buckets 列表
 ///
+/// ##### 阻塞代码示例
+///
+/// ```
+/// use qiniu_credential::Credential;
+/// use qiniu_http_client::{Authorization, HttpClient, Region, RegionsProviderEndpoints, ServiceName};
+///
+/// # fn example() -> anyhow::Result<()> {
+/// let region = Region::builder("z0")
+///     .add_uc_preferred_endpoint("uc-qos.pocdemo.qiniu.io".parse()?)
+///     .build();
+/// let credential = Credential::new("abcdefghklmnopq", "1234567890");
+/// let bucket_names: Vec<String> = HttpClient::default()
+///     .get(&[ServiceName::Uc], RegionsProviderEndpoints::new(region))
+///     .use_https(false)
+///     .authorization(Authorization::v2(credential))
+///     .accept_json()
+///     .path("/buckets")
+///     .call()?
+///     .parse_json()?
+///     .into_body();
+/// # Ok(())
+/// # }
+/// ```
+///
+/// ##### 异步代码示例
+///
 /// ```
 /// use qiniu_credential::Credential;
 /// use qiniu_http_client::{Authorization, HttpClient, Region, RegionsProviderEndpoints, ServiceName};
@@ -59,6 +86,14 @@ pub struct HttpClient {
     inner: Arc<HttpClientInner>,
 }
 
+impl HttpClient {
+    #[allow(dead_code)]
+    fn assert() {
+        assert_impl!(Send: Self);
+        assert_impl!(Sync: Self);
+    }
+}
+
 #[derive(Debug)]
 struct HttpClientInner {
     use_https: bool,
@@ -575,6 +610,12 @@ impl HttpClientBuilder {
             }),
         }
     }
+
+    #[allow(dead_code)]
+    fn assert() {
+        assert_impl!(Send: Self);
+        assert_impl!(Sync: Self);
+    }
 }
 
 impl Default for HttpClientBuilder {
