@@ -1,7 +1,11 @@
+use assert_impl::assert_impl;
 use mime::Mime;
 use once_cell::sync::Lazy;
 use percent_encoding::{utf8_percent_encode, AsciiSet, CONTROLS};
-use qiniu_http::{header::CONTENT_TYPE, HeaderMap, HeaderName, HeaderValue};
+use qiniu_http::{
+    header::{IntoHeaderName, CONTENT_TYPE},
+    HeaderMap, HeaderValue,
+};
 use qiniu_utils::{smallstr::SmallString, wrap_smallstr};
 use rand::random;
 use regex::Regex;
@@ -136,6 +140,14 @@ impl<P> Multipart<P> {
     }
 }
 
+impl<P: Sync + Send> Multipart<P> {
+    #[allow(dead_code)]
+    fn ignore() {
+        assert_impl!(Send: Self);
+        assert_impl!(Sync: Self);
+    }
+}
+
 /// Multipart 表单组件元信息
 #[derive(Default, Debug)]
 pub struct PartMetadata {
@@ -154,8 +166,8 @@ impl PartMetadata {
     /// 添加表单组件的 HTTP 头
     #[inline]
     #[must_use]
-    pub fn add_header(mut self, name: impl Into<HeaderName>, value: impl Into<HeaderValue>) -> Self {
-        self.headers.insert(name.into(), value.into());
+    pub fn add_header(mut self, name: impl IntoHeaderName, value: impl Into<HeaderValue>) -> Self {
+        self.headers.insert(name, value.into());
         self
     }
 
@@ -178,6 +190,14 @@ impl<B> Part<B> {
     }
 }
 
+impl<B: Sync + Send> Part<B> {
+    #[allow(dead_code)]
+    fn ignore() {
+        assert_impl!(Send: Self);
+        assert_impl!(Sync: Self);
+    }
+}
+
 mod sync_part {
     use super::*;
     use std::{
@@ -578,7 +598,7 @@ mod tests {
         drop(file);
 
         let mut multipart = SyncMultipart::new()
-            .add_part("bytes1", SyncPart::bytes(&b"part1"[..]))
+            .add_part("bytes1", SyncPart::bytes(b"part1".as_slice()))
             .add_part("text1", SyncPart::text("value1"))
             .add_part(
                 "text2",
@@ -634,7 +654,7 @@ mod tests {
         drop(file);
 
         let mut multipart = AsyncMultipart::new()
-            .add_part("bytes1", AsyncPart::bytes(&b"part1"[..]))
+            .add_part("bytes1", AsyncPart::bytes(b"part1".as_slice()))
             .add_part("text1", AsyncPart::text("value1"))
             .add_part(
                 "text2",
