@@ -28,9 +28,9 @@
 //! 通过对七牛特有的状态码和响应头进行合理的处理和重试，竭力保证七牛 API 可以调用成功。
 //!
 //! 该接口库可以通过启用不同的功能来选择不同的客户端实现，
-//! 例如可以通过启用 `ureq` 功能导入 `qiniu-http-ureq` 库作为 HTTP 客户端，
-//! 通过启用 `reqwest` 功能导入 `qiniu-http-reqwest` 库作为 HTTP 客户端，
-//! 通过启用 `isahc` 功能导入 `qiniu-http-isahc` 库作为 HTTP 客户端，
+//! 例如可以通过启用 `ureq` 功能导入 `qiniu-ureq` 库作为 HTTP 客户端，
+//! 通过启用 `reqwest` 功能导入 `qiniu-reqwest` 库作为 HTTP 客户端，
+//! 通过启用 `isahc` 功能导入 `qiniu-isahc` 库作为 HTTP 客户端，
 //! 您也可以显式传入任何基于 `qiniu-http` 接口的 HTTP 客户端实现来提供给 `qiniu-http-client` 使用。
 //!
 //! `qiniu-http-client` 提供的功能主要分为两个大类：区域相关和 HTTP 客户端逻辑相关。
@@ -114,6 +114,40 @@
 //! [`RandomizedBackoff`] 为一个 [`Backoff`] 实例返回的退避时长增加随机范围，即返回的退避时长随机化。
 //! 可以通过配置 [`HttpClientBuilder::backoff`] 来指定使用哪个退避器，如果不指定，默认使用 [`ExponentialBackoff`]，并使用 [`LimitedBackoff`] 和 [`RandomizedBackoff`] 对其进行包装。
 //!
+//! ### 功能描述
+//!
+//! #### `async`
+//!
+//! 启用异步接口。
+//!
+//! #### `ureq`
+//!
+//! 导入 `qiniu-ureq` 作为 HTTP 客户端。
+//!
+//! #### `isahc`
+//!
+//! 导入 `qiniu-isahc` 作为 HTTP 客户端。
+//!
+//! #### `reqwest`
+//!
+//! 导入 `qiniu-reqwest` 作为 HTTP 客户端。
+//!
+//! #### `c_ares`
+//!
+//! 启用 `c-ares` 库作为 DNS 解析器。
+//!
+//! #### `trust_dns`
+//!
+//! 启用 `trust-dns` 库作为 DNS 解析器。
+//!
+//! #### `dns-over-https`
+//!
+//! 启用 `trust-dns` 库作为 DNS 解析器，并使用 DOH 协议。
+//!
+//! #### `dns-over-tls`
+//!
+//! 启用 `trust-dns` 库作为 DNS 解析器，并使用 DOT 协议。
+//!
 //! ### 代码示例
 //!
 //! #### 私有云获取当前账户的 Buckets 列表
@@ -299,24 +333,26 @@ pub use futures::io::AsyncRead;
 
 pub use client::{
     ApiResult, Authorization, AuthorizationError, AuthorizationProvider, AuthorizationResult, Backoff, BackoffOptions,
-    CachedResolver, CallbackContext, ChainedResolver, ChainedResolverBuilder, Chooser, ChooserFeedback,
-    CredentialAuthorizationV1, CredentialAuthorizationV2, DirectChooser, DownloadUrlCredentialAuthorization,
-    ErrorRetrier, ExponentialBackoff, ExtendedCallbackContext, FieldName, FileName, FixedBackoff, GotBackoffDuration,
-    HttpClient, HttpClientBuilder, Idempotent, IpChooser, IpChooserBuilder, LimitedBackoff, LimitedRetrier, Multipart,
-    NeverEmptyHandedChooser, NeverRetrier, Part, PartMetadata, QueryPair, QueryPairKey, QueryPairValue,
-    RandomizedBackoff, Ratio, RequestBuilder, RequestBuilderParts, RequestRetrier, RequestRetrierOptions,
-    ResolveAnswers, ResolveOptions, ResolveResult, Resolver, Response, ResponseError, ResponseErrorKind,
-    RetriedStatsInfo, RetryDecision, RetryResult, ShuffledChooser, ShuffledResolver, SimpleResolver,
-    SimplifiedCallbackContext, SubnetChooser, SubnetChooserBuilder, SyncMultipart, SyncPart, SyncPartBody,
-    SyncRequestBody, SyncRequestBuilder, SyncResponse, TimeoutResolver, UploadTokenAuthorization, NO_BACKOFF,
+    CachedResolver, CallbackContext, ChainedResolver, ChainedResolverBuilder, ChooseOptions, ChooseOptionsBuilder,
+    Chooser, ChooserFeedback, CredentialAuthorizationV1, CredentialAuthorizationV2, DirectChooser,
+    DownloadUrlCredentialAuthorization, ErrorRetrier, ExponentialBackoff, ExtendedCallbackContext, FieldName, FileName,
+    FixedBackoff, GotBackoffDuration, HttpClient, HttpClientBuilder, Idempotent, IpChooser, IpChooserBuilder,
+    LimitedBackoff, LimitedRetrier, Multipart, NeverEmptyHandedChooser, NeverRetrier, Part, PartMetadata, QueryPair,
+    QueryPairKey, QueryPairValue, RandomizedBackoff, Ratio, RequestBuilder, RequestBuilderParts, RequestParts,
+    RequestRetrier, RequestRetrierOptions, ResolveAnswers, ResolveOptions, ResolveResult, Resolver, Response,
+    ResponseError, ResponseErrorKind, RetriedStatsInfo, RetryDecision, RetryResult, ShuffledChooser, ShuffledResolver,
+    SimpleResolver, SimplifiedCallbackContext, SubnetChooser, SubnetChooserBuilder, SyncMultipart, SyncPart,
+    SyncPartBody, SyncRequestBody, SyncRequestBuilder, SyncResponse, TimeoutResolver, UploadTokenAuthorization,
+    NO_BACKOFF,
 };
 pub use http::{CallbackResult, SyncResponseBody};
 pub use regions::{
-    AllRegionsProvider, BucketDomainsProvider, BucketDomainsQueryer, BucketDomainsQueryerBuilder,
-    BucketRegionsProvider, BucketRegionsQueryer, BucketRegionsQueryerBuilder, DomainWithPort, DomainWithPortParseError,
-    Endpoint, EndpointParseError, Endpoints, EndpointsBuilder, EndpointsGetOptions, EndpointsGetOptionsBuilder,
-    EndpointsProvider, GotRegion, GotRegions, InvalidServiceName, IpAddrWithPort, IpAddrWithPortParseError, Region,
-    RegionBuilder, RegionsGetOptions, RegionsProvider, RegionsProviderEndpoints, ServiceName, StaticRegionsProvider,
+    AllRegionsProvider, AllRegionsProviderBuilder, BucketDomainsProvider, BucketDomainsQueryer,
+    BucketDomainsQueryerBuilder, BucketRegionsProvider, BucketRegionsQueryer, BucketRegionsQueryerBuilder,
+    DomainWithPort, DomainWithPortParseError, Endpoint, EndpointParseError, Endpoints, EndpointsBuilder,
+    EndpointsGetOptions, EndpointsGetOptionsBuilder, EndpointsProvider, GotRegion, GotRegions, InvalidServiceName,
+    IpAddrWithPort, IpAddrWithPortParseError, Region, RegionBuilder, RegionsGetOptions, RegionsProvider,
+    RegionsProviderEndpoints, ServiceName, StaticRegionsProvider,
 };
 pub use upload_token::{BucketName, ObjectName};
 
