@@ -1,3 +1,4 @@
+use qiniu_http::uri::Authority;
 use serde::{Deserialize, Serialize};
 use std::{
     fmt::{self, Display},
@@ -88,6 +89,13 @@ impl From<(Box<str>, Option<NonZeroU16>)> for DomainWithPort {
     }
 }
 
+impl From<Authority> for DomainWithPort {
+    #[inline]
+    fn from(authority: Authority) -> Self {
+        Self::new(authority.host(), authority.port_u16().and_then(NonZeroU16::new))
+    }
+}
+
 impl From<String> for DomainWithPort {
     #[inline]
     fn from(domain: String) -> Self {
@@ -413,6 +421,13 @@ impl From<(Box<str>, NonZeroU16)> for Endpoint {
     }
 }
 
+impl From<Authority> for Endpoint {
+    #[inline]
+    fn from(authority: Authority) -> Self {
+        DomainWithPort::from(authority).into()
+    }
+}
+
 impl From<String> for Endpoint {
     #[inline]
     fn from(domain: String) -> Self {
