@@ -14,6 +14,7 @@ pub use endpoints_provider::{
 };
 pub use region::{Region, RegionBuilder};
 pub use regions_provider::{
-    AllRegionsProvider, BucketRegionsProvider, BucketRegionsQueryer, BucketRegionsQueryerBuilder,
-    GetOptions as RegionsGetOptions, GotRegion, GotRegions, RegionsProvider, StaticRegionsProvider,
+    AllRegionsProvider, AllRegionsProviderBuilder, BucketRegionsProvider, BucketRegionsQueryer,
+    BucketRegionsQueryerBuilder, GetOptions as RegionsGetOptions, GotRegion, GotRegions, RegionsProvider,
+    StaticRegionsProvider,
 };
